﻿Imports XCM
Imports XSP
Imports System.Runtime.ConstrainedExecution

''' ---------------------------------------------
''' <summary>
''' 入力チェックエラー一覧表印刷　Report出力クラス
''' </summary>
''' <remarks>
''' Copyright 2010 FUJITSU SHIKOKU SYSTEMS LIMITED All rights reserved.<BR/>
''' FUJITSU SHIKOKU SYSTEMS LIMITED CONFIDENTIAL<BR/>
''' </remarks>
''' ---------------------------------------------
Public Class MEN010R060

#Region "解放処理"
    '確実な解放処理を実行するために指定
    Inherits CriticalFinalizerObject
    '解放処理を実装する為に指定
    Implements IDisposable

    ''' ---------------------------------------------
    ''' <summary>
    ''' Dispose（解放処理）※外からはよばない
    ''' </summary>
    ''' <param name="disposing"></param>
    ''' <remarks>
	''' 2010/12/16 新規作成 CS)徳増<BR/>
	''' </remarks>
    ''' ---------------------------------------------
    Protected Overloads Sub Dispose(ByVal disposing As Boolean)
        If disposing Then
            pFrm = Nothing                          'フォーム
        End If
    End Sub

    ''' ---------------------------------------------
    ''' <summary>
    ''' Finalize（解放処理）
    ''' </summary>
    ''' <remarks>
	''' 2010/12/16 新規作成 CS)徳増<BR/>
	''' </remarks>
    ''' ---------------------------------------------
    Public Overloads Sub Dispose() Implements IDisposable.Dispose
        Dispose(True)
        MyBase.Finalize()
        GC.SuppressFinalize(Me)
    End Sub

    ''' ---------------------------------------------
    ''' <summary>
    ''' Finalize（解放処理）※外からはよばない
    ''' </summary>
    ''' <remarks>
	''' 2010/12/16 新規作成 CS)徳増<BR/>
	''' </remarks>
    ''' ---------------------------------------------
    Protected Overrides Sub Finalize()
        Dispose(False)
        MyBase.Finalize()
    End Sub
#End Region

#Region "変数"

    'IN項目
    Private pFrm As frmBase = Nothing                                   'フォーム

#End Region

#Region "コンスタント"

    '帳票タイトル(頭書コメントトップが空白時使用)
    Private Const LEDGERSHEET_TITLE As String = "入力チェックエラー一覧"

#End Region

#Region "コンストラクタ"

    ''' ---------------------------------------------
    ''' <summary>
    ''' コンストラクタ
    ''' </summary>
    ''' <param name="pForm">frmBase</param>
    ''' <remarks>
	''' 2010/12/16 新規作成 CS)徳増<BR/>
	''' </remarks>
    ''' ---------------------------------------------
    Sub New(ByVal pForm As Form)
        'IN項目引き継ぎ
        pFrm = pForm                    '画面ID
    End Sub

#End Region

#Region "メソッド"

    ''' ---------------------------------------------
    ''' <summary>
    ''' 印刷・プレビュー処理（入力チェックエラー一覧表印刷）
    ''' </summary>
    ''' <param name="pValuePrint">TRUE:印刷 FALSE:プレビュー</param>	
    ''' <remarks>
    ''' 2010/12/16 新規作成 CS)徳増<BR/>
    ''' </remarks>
    ''' ---------------------------------------------
    Public Function Prn_INPUT_CHK(ByVal pValuePrint As Boolean) As Boolean
        pFrm.log(clsSysMst.logLevel.DBG, "Prn_INPUT_CHK", "印刷・プレビュー処理(入力チェックエラー一覧表印刷） START")

        Dim FilePath As String = Nothing                                'MDBファイルパス（フルパス）
        Dim cliAccess As clsXTM_PRINTSETTING_ACCESS = Nothing           'ACCESS設定情報アクセスクラス
        Dim datAccess As datXTM_PRINTSETTING_ACCESS_OneRec = Nothing    'ACCESS設定情報データクラス
		Dim datHeader As datHeader = Nothing							'ヘッダーデータクラス
		Dim cliCom As clsCom = Nothing									'共通クラス
		Dim intCnt As Integer = 0
		Try
			'アクセスクラスのインスタンス化
			cliAccess = New clsXTM_PRINTSETTING_ACCESS
			cliCom = New clsCom

			'ヘッダー情報作成
			datHeader = Me.getHeaderData()

			'印刷設定情報取得
			datAccess = cliAccess.getAccessSettingOneRec(Me.pFrm.Name, Me.GetType.Name)
			If datAccess Is Nothing Then
				Return False
			End If

			'MDBファイルパス設定
			FilePath = cliCom.setReportPath(datAccess.FILE_NM)

			Using db As clsDB = New clsDB(clsSysMst.ctlConfigData), _
			   cliReportFunc As clsReportFunc = New clsReportFunc(pFrm, FilePath, datAccess.REPORT_NM, pValuePrint)

				'入力チェック情報のデータ件数をチェック
				intCnt = Me.getDetailDataCount(db)

				'データ件数が０件の場合はメッセージを表示し、終了
				If intCnt = 0 Then
					pFrm.showMsg("I0001")	 '該当するデータはありませんでした。
					Return False
				End If

				'ヘッダーワークテーブルの削除
				Call cliReportFunc.exeHeaderDel(db, datAccess.REPORT_NM, True)

				'ヘッダーワークテーブルの追加
				Call cliReportFunc.exeHeaderIns(db, datHeader, True)

				'AcPrint内でレポートの存在チェックを行う
				'そのため、独自ロジックは組まない。
				If Not cliReportFunc.AcPrint(datAccess.NUMBERPRINTED) Then
					Return False
				End If
			End Using
			Return True
		Catch ex As Exception
			Throw
		Finally
			FilePath = Nothing
			cliAccess = Nothing
			datAccess = Nothing
			datHeader = Nothing
			cliCom = Nothing
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' ヘッダーデータ取得
	''' </summary>
	''' <returns>ヘッダーデータ</returns>
	''' <remarks>
	''' 2010/12/16 新規作成 CS)徳増<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function getHeaderData() As datHeader
		clsSysMst.logEx(clsSysMst.logLevel.DBG, "MEN", Me.GetType.Name, "getHeaderData", "入力チェックエラー一覧表印刷", "入力チェックエラー一覧表印刷（Report）", "ヘッダーデータ取得 START")
		Dim retHeader As datHeader
		Try
			retHeader = New datHeader
			With retHeader
				'帳票ID
				.PRT_ID = Me.GetType.Name
				'タイトル	
				.TITLE_NM = LEDGERSHEET_TITLE
			End With
			Return retHeader
		Catch ex As Exception
			Throw
		Finally
			retHeader = Nothing
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 明細データ件数取得（入力チェック情報）
	''' </summary>
	''' <param name="db">ＤＢクラス</param>
	''' <returns>件数</returns>
	''' <remarks>
	''' 2010/12/16 新規作成 CS)徳増<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function getDetailDataCount(ByVal db As clsDB) As Integer
		Dim arData As ArrayList = Nothing
		Dim dbData As datMEN010R060_Cnt = Nothing
		Dim iRet As Long = 0
		Try
			arData = New ArrayList()
			db.setSQL(sqlMEN010R060.sqlSel_MTW_INPUT_CHK_Cnt)				'SELECT文設定
			db.setParam(sqlReport.prmHOST_NM, clsDB.Enum_dbType.dbNVarChar)	'ホスト名
			db.setVal(sqlReport.prmHOST_NM, clsConst.CST_HOST_NM)
			iRet = db.execQuery(GetType(datMEN010R060_Cnt), arData)	'値取得
			If iRet > 0 Then										'レコードあり
				dbData = DirectCast(arData(0), datMEN010R060_Cnt)
				Return dbData.CNT
			Else
				Return 0
			End If
		Catch ex As Exception
			Throw
		Finally
			'メモリ解放
			arData = Nothing
			dbData = Nothing
		End Try
	End Function

#End Region

End Class