﻿Imports XSP
Imports XCM

''' ---------------------------------------------
''' <summary>
''' ＡＤＬスコア
''' </summary>
''' <remarks>
''' Copyright 2010 FUJITSU SHIKOKU SYSTEMS LIMITED All rights reserved.<BR/>
''' FUJITSU SHIKOKU SYSTEMS LIMITED CONFIDENTIAL<BR/>
''' </remarks>
''' ---------------------------------------------
Public Class MEN130F021

#Region "コンスタント"

	'画面タイトル
	Private Const HSP_TITLE As String = "入院時ＡＤＬスコア"
	Private Const OUTHSP_TITLE As String = "退院時ＡＤＬスコア"

#End Region

#Region "変数"

	'画面呼び出し時のパラメータ(コンストラクタでセット)
	Private pADLScoreKind As clsMENCOMMON.Enum_AdlScoreKind							'画面種類
	Private pADLItemName As String													'ＡＤＬスコアの項目名
	Private pADLValue As String														'ＡＤＬスコアの内容
	Private pIndispensableFlg As Boolean											'必須フラグ

	'入力値保持用
	Private pADLValue1 As String													'食事
	Private pADLValue2 As String													'移乗
	Private pADLValue3 As String													'整容
	Private pADLValue4 As String													'トイレの動作、トイレの使用
	Private pADLValue5 As String													'入浴
	Private pADLValue6 As String													'平地歩行
	Private pADLValue7 As String													'階段
	Private pADLValue8 As String													'更衣
	Private pADLValue9 As String													'排便管理
	Private pADLValue10 As String													'排尿管理

	Private updFlg As clsMENCOMMON.Enum_UpdFlg = clsMENCOMMON.Enum_UpdFlg.eInit		'更新フラグ

#End Region

#Region "コンストラクタ"

	''' ---------------------------------------------
	''' <summary>
	''' コンストラクタ(DPC2008モード)
	''' </summary>
	''' <param name="execMode">処理モード</param>
	''' <param name="adlScoreKind">画面種類</param>
	''' <param name="adlItemName">ＡＤＬスコアの項目名</param>
	''' <param name="adlValue">ＡＤＬスコアの内容</param>
	''' <remarks>
	''' 2010/10/29 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub New(ByVal execMode As Enum_ExeMode, ByVal adlScoreKind As clsMENCOMMON.Enum_AdlScoreKind, ByVal adlItemName As String, ByVal adlValue As String)
		Me.New(execMode, adlScoreKind, adlItemName, adlValue, False)
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' コンストラクタ(DPC2010モード)
	''' </summary>
	''' <param name="execMode">処理モード</param>
	''' <param name="adlScoreKind">画面種類</param>
	''' <param name="adlItemName">ＡＤＬスコアの項目名</param>
	''' <param name="adlValue">ＡＤＬスコアの内容</param>
	''' <param name="indispensableFlg">必須フラグ</param>
	''' <remarks>
	''' 2010/10/29 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Sub New(ByVal execMode As Enum_ExeMode, ByVal adlScoreKind As clsMENCOMMON.Enum_AdlScoreKind, ByVal adlItemName As String, ByVal adlValue As String, ByVal indispensableFlg As Boolean)
		' この呼び出しはデザイナーで必要です。
		InitializeComponent()

		' InitializeComponent() 呼び出しの後で初期化を追加します。
		Me.ExeMode = execMode					'処理モード
		Me.pADLScoreKind = adlScoreKind			'画面種類
		Me.pADLItemName = adlItemName			'ＡＤＬスコアの項目名
		Me.pADLValue = adlValue					'ＡＤＬスコアの内容
		Me.pIndispensableFlg = indispensableFlg	'必須フラグ

		' 画面種類により、タイトルを変更する。
		Select Case Me.pADLScoreKind
			Case clsMENCOMMON.Enum_AdlScoreKind.eHsp
				' 入院時
				Me.Text = HSP_TITLE
				Me.Title = HSP_TITLE
			Case clsMENCOMMON.Enum_AdlScoreKind.eOutHsp
				' 退院時
				Me.Text = OUTHSP_TITLE
				Me.Title = OUTHSP_TITLE
			Case Else
		End Select
	End Sub

#End Region

#Region "イベント"

	''' ---------------------------------------------
	''' <summary>
	''' 画面終了時イベント
	''' </summary>
	''' <param name="sender"></param>
	''' <param name="e"></param>
	''' <remarks>
	''' 2010/12/06 新規作成　CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Sub MEN130F021_FormClosing(ByVal sender As Object, ByVal e As System.Windows.Forms.FormClosingEventArgs) Handles Me.FormClosing
		log(clsSysMst.logLevel.NRM, "MEN130F021_FormClosing", "画面終了時イベント Start")
		Try
			' 画面途中でエラーの場合は処理しない
			If Me.LoadError OrElse e.Cancel Then
				Exit Try
			End If
		Catch ex As Exception
			e.Cancel = True		'エラー時は画面を閉じない
			Me.ErrorProc(ex)
		Finally
			' 変数の解放は ClosedProc に記述する
			Me.ClosedProc(e.Cancel)
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' 画面ロード時イベント
	''' </summary>
	''' <param name="sender"></param>
	''' <param name="e"></param>
	''' <remarks>
	''' 2010/11/05 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Sub MEN130F021_Load(ByVal sender As Object, ByVal e As System.EventArgs) Handles Me.Load
		If Me.DesignMode OrElse Me.LoadError Then
			Exit Sub
		End If
		log(clsSysMst.logLevel.NRM, "MEN130F021_Load", "画面ロード時イベント Start")
		Try
			'戻り値の初期値
			Me.ReturnKey = Me.pADLScoreKind

			' 必須入力前景色
			If Me.pIndispensableFlg = True Then
				Me.lbl001MEN130F021.ForeColor = clsConst.CST_REQUIRED_COLOR		'食事
				Me.lbl004MEN130F021.ForeColor = clsConst.CST_REQUIRED_COLOR		'移乗
				Me.lbl007MEN130F021.ForeColor = clsConst.CST_REQUIRED_COLOR		'整容
				Me.lbl010MEN130F021.ForeColor = clsConst.CST_REQUIRED_COLOR		'トイレの動作、トイレの使用
				Me.lbl013MEN130F021.ForeColor = clsConst.CST_REQUIRED_COLOR		'入浴
				Me.lbl016MEN130F021.ForeColor = clsConst.CST_REQUIRED_COLOR		'平地歩行
				Me.lbl019MEN130F021.ForeColor = clsConst.CST_REQUIRED_COLOR		'階段
				Me.lbl022MEN130F021.ForeColor = clsConst.CST_REQUIRED_COLOR		'更衣
				Me.lbl025MEN130F021.ForeColor = clsConst.CST_REQUIRED_COLOR		'排便管理
				Me.lbl028MEN130F021.ForeColor = clsConst.CST_REQUIRED_COLOR		'排尿管理
			End If

			'処理モード「参照」の場合
			If Me.ExeMode = Enum_ExeMode.eReference Then
				'保存ボタンを非表示にする。
				Me.btn015MEN000F010.Visible = False
				'全ての入力項目を参照モードにする。
				clsMENCOMMON.setAllItemCanInput(Me, False)
			End If

			' 各コンボボックスを初期設定する。
			Me.setComboBoxInit()
		Catch ex As Exception
			Me.ErrorProc(ex)
			Me.EndProc4Load()
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' 画面オープン時イベント
	''' </summary>
	''' <param name="sender"></param>
	''' <param name="e"></param>
	''' <remarks>
	''' 2010/11/05 新規作成 CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Sub MEN130F021_Shown(ByVal sender As Object, ByVal e As System.EventArgs) Handles Me.Shown
		If Me.DesignMode OrElse Me.LoadError Then
			Exit Sub
		End If
		log(clsSysMst.logLevel.NRM, "MEN130F021_Shown", "画面オープン時イベント Start")
		Dim cliCom As clsCom = Nothing
		Try
			'コンストラクタ引数のＡＤＬスコアに設定がある場合、内容を各桁ごとに分解し、画面の各項目を表示する。
			cliCom = New clsCom
			If Not String.IsNullOrEmpty(Me.pADLValue) Then
				For i As Integer = 0 To Me.pADLValue.Length - 1
					Select Case i
						Case 0
							'食事
							cliCom.setComboValue(Me.cmb002MEN020F021, Me.pADLValue.Substring(0, 1))
						Case 1
							'移乗
							cliCom.setComboValue(Me.cmb005MEN020F021, Me.pADLValue.Substring(1, 1))
						Case 2
							'整容
							cliCom.setComboValue(Me.cmb008MEN020F021, Me.pADLValue.Substring(2, 1))
						Case 3
							'トイレの動作、トイレの使用
							cliCom.setComboValue(Me.cmb011MEN020F021, Me.pADLValue.Substring(3, 1))
						Case 4
							'入浴
							cliCom.setComboValue(Me.cmb014MEN020F021, Me.pADLValue.Substring(4, 1))
						Case 5
							'平地歩行
							cliCom.setComboValue(Me.cmb017MEN020F021, Me.pADLValue.Substring(5, 1))
						Case 6
							'階段
							cliCom.setComboValue(Me.cmb020MEN020F021, Me.pADLValue.Substring(6, 1))
						Case 7
							'更衣
							cliCom.setComboValue(Me.cmb023MEN020F021, Me.pADLValue.Substring(7, 1))
						Case 8
							'排便管理
							cliCom.setComboValue(Me.cmb026MEN020F021, Me.pADLValue.Substring(8, 1))
						Case 9
							'排尿管理
							cliCom.setComboValue(Me.cmb029MEN020F021, Me.pADLValue.Substring(9, 1))
						Case Else
					End Select
				Next
				Me.updFlg = clsMENCOMMON.Enum_UpdFlg.eInit
			Else
				Me.updFlg = clsMENCOMMON.Enum_UpdFlg.eEmpty
			End If

			'内部変数に入力値を保持する
			Me.getInputData()

			'先頭の項目にフォーカス
			Me.cmb002MEN020F021.Focus()
		Catch ex As Exception
			Me.ErrorProc(ex)
			Me.EndProc4Shown()
		Finally
			cliCom = Nothing
		End Try
	End Sub

#End Region

#Region "メソッド"

	''' ---------------------------------------------
	''' <summary>
	''' 各コンボボックスの初期設定
	''' </summary>
	''' <remarks>
	''' 2010/11/05 新規作成　CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Sub setComboBoxInit()
		log(clsSysMst.logLevel.DBG, "setComboBoxInit", "コンボボックス初期設定 Start")
		Dim cliCommon As clsMENCOMMON = Nothing
		Dim cmbMb()() As String
		Try
			cliCommon = New clsMENCOMMON
			'食事
			cmbMb = {New String() {"2", "自立"}, New String() {"1", "一部介助"}, New String() {"0", "全介助"}, New String() {"9", "不明"}}
			cliCommon.setComboBoxData(Me.cmb002MEN020F021, cmbMb)
			'移乗
			cmbMb = {New String() {"3", "自立"}, New String() {"2", "一部介助（軽度）"}, New String() {"1", "一部介助（高度）"}, New String() {"0", "全介助"}, New String() {"9", "不明"}}
			cliCommon.setComboBoxData(Me.cmb005MEN020F021, cmbMb)
			'整容
			cmbMb = {New String() {"1", "自立"}, New String() {"0", "全介助"}, New String() {"9", "不明"}}
			cliCommon.setComboBoxData(Me.cmb008MEN020F021, cmbMb)
			'トイレの動作、トイレの使用
			cmbMb = {New String() {"2", "自立"}, New String() {"1", "一部介助"}, New String() {"0", "全介助"}, New String() {"9", "不明"}}
			cliCommon.setComboBoxData(Me.cmb011MEN020F021, cmbMb)
			'入浴
			cmbMb = {New String() {"1", "自立"}, New String() {"0", "全介助"}, New String() {"9", "不明"}}
			cliCommon.setComboBoxData(Me.cmb014MEN020F021, cmbMb)
			'平地歩行
			cmbMb = {New String() {"3", "自立"}, New String() {"2", "一部介助（歩く）"}, New String() {"1", "一部介助（車いす）"}, New String() {"0", "全介助"}, New String() {"9", "不明"}}
			cliCommon.setComboBoxData(Me.cmb017MEN020F021, cmbMb)
			'階段
			cmbMb = {New String() {"2", "自立"}, New String() {"1", "一部介助"}, New String() {"0", "全介助"}, New String() {"9", "不明"}}
			cliCommon.setComboBoxData(Me.cmb020MEN020F021, cmbMb)
			'更衣
			cmbMb = {New String() {"2", "自立"}, New String() {"1", "一部介助"}, New String() {"0", "全介助"}, New String() {"9", "不明"}}
			cliCommon.setComboBoxData(Me.cmb023MEN020F021, cmbMb)
			'排便管理
			cmbMb = {New String() {"2", "自立"}, New String() {"1", "一部介助"}, New String() {"0", "全介助"}, New String() {"9", "不明"}}
			cliCommon.setComboBoxData(Me.cmb026MEN020F021, cmbMb)
			'排尿管理
			cmbMb = {New String() {"2", "自立"}, New String() {"1", "一部介助"}, New String() {"0", "全介助"}, New String() {"9", "不明"}}
			cliCommon.setComboBoxData(Me.cmb029MEN020F021, cmbMb)
		Catch ex As Exception
			Throw
		Finally
			cliCommon = Nothing
			cmbMb = Nothing
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' 入力値を内部変数に保持
	''' </summary>
	''' <remarks>
	''' 2010/11/05 新規作成　CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Sub getInputData()
		log(clsSysMst.logLevel.DBG, "getInputData", "入力値を内部変数に保持 Start")
		Try
			Me.pADLValue1 = Me.cmb002MEN020F021.Text	'食事
			Me.pADLValue2 = Me.cmb005MEN020F021.Text	'移乗
			Me.pADLValue3 = Me.cmb008MEN020F021.Text	'整容
			Me.pADLValue4 = Me.cmb011MEN020F021.Text	'トイレの動作、トイレの使用
			Me.pADLValue5 = Me.cmb014MEN020F021.Text	'入浴
			Me.pADLValue6 = Me.cmb017MEN020F021.Text	'平地歩行
			Me.pADLValue7 = Me.cmb020MEN020F021.Text	'階段
			Me.pADLValue8 = Me.cmb023MEN020F021.Text	'更衣
			Me.pADLValue9 = Me.cmb026MEN020F021.Text	'排便管理
			Me.pADLValue10 = Me.cmb029MEN020F021.Text	'排尿管理
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' 入力値変更チェック
	''' </summary>
	''' <remarks>
	''' 2010/11/05 新規作成　CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function chkUpdate() As Boolean
		log(clsSysMst.logLevel.DBG, "chkUpdate", "入力値変更チェック Start")
		Dim bRet As Boolean = False
		Try
			'食事
			If Me.pADLValue1 <> Me.cmb002MEN020F021.Text Then bRet = True
			'移乗
			If Me.pADLValue2 <> Me.cmb005MEN020F021.Text Then bRet = True
			'整容
			If Me.pADLValue3 <> Me.cmb008MEN020F021.Text Then bRet = True
			'トイレの動作、トイレの使用
			If Me.pADLValue4 <> Me.cmb011MEN020F021.Text Then bRet = True
			'入浴
			If Me.pADLValue5 <> Me.cmb014MEN020F021.Text Then bRet = True
			'平地歩行
			If Me.pADLValue6 <> Me.cmb017MEN020F021.Text Then bRet = True
			'階段
			If Me.pADLValue7 <> Me.cmb020MEN020F021.Text Then bRet = True
			'更衣
			If Me.pADLValue8 <> Me.cmb023MEN020F021.Text Then bRet = True
			'排便管理
			If Me.pADLValue9 <> Me.cmb026MEN020F021.Text Then bRet = True
			'排尿管理
			If Me.pADLValue10 <> Me.cmb029MEN020F021.Text Then bRet = True

			Return bRet
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 入力チェック
	''' </summary>
	''' <remarks>
	''' 2010/11/05 新規作成　CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function chkInput() As Boolean
		log(clsSysMst.logLevel.DBG, "chkInput", "入力チェック Start")
		Dim inputCnt As Integer = 10
		Try
			'「食事」コンボボックスが未入力の場合
			If String.IsNullOrEmpty(Me.cmb002MEN020F021.Text) Then
				If Me.pIndispensableFlg = True Then
					Me.addErrList("E0001", Me.cmb002MEN020F021.Name, Me.lbl001MEN130F021.Text, Nothing)
				End If
				inputCnt -= 1
			End If
			'「移乗」コンボボックスが未入力の場合
			If String.IsNullOrEmpty(Me.cmb005MEN020F021.Text) Then
				If Me.pIndispensableFlg = True Then
					Me.addErrList("E0001", Me.cmb005MEN020F021.Name, Me.lbl004MEN130F021.Text, Nothing)
				End If
				inputCnt -= 1
			End If
			'「整容」コンボボックスが未入力の場合
			If String.IsNullOrEmpty(Me.cmb008MEN020F021.Text) Then
				If Me.pIndispensableFlg = True Then
					Me.addErrList("E0001", Me.cmb008MEN020F021.Name, Me.lbl007MEN130F021.Text, Nothing)
				End If
				inputCnt -= 1
			End If
			'「トイレの動作、トイレの使用」コンボボックスが未入力の場合
			If String.IsNullOrEmpty(Me.cmb011MEN020F021.Text) Then
				If Me.pIndispensableFlg = True Then
					Me.addErrList("E0001", Me.cmb011MEN020F021.Name, Me.lbl010MEN130F021.Text, Nothing)
				End If
				inputCnt -= 1
			End If
			'「入浴」コンボボックスが未入力の場合
			If String.IsNullOrEmpty(Me.cmb014MEN020F021.Text) Then
				If Me.pIndispensableFlg = True Then
					Me.addErrList("E0001", Me.cmb014MEN020F021.Name, Me.lbl013MEN130F021.Text, Nothing)
				End If
				inputCnt -= 1
			End If
			'「平地歩行」コンボボックスが未入力の場合
			If String.IsNullOrEmpty(Me.cmb017MEN020F021.Text) Then
				If Me.pIndispensableFlg = True Then
					Me.addErrList("E0001", Me.cmb017MEN020F021.Name, Me.lbl016MEN130F021.Text, Nothing)
				End If
				inputCnt -= 1
			End If
			'「階段」コンボボックスが未入力の場合
			If String.IsNullOrEmpty(Me.cmb020MEN020F021.Text) Then
				If Me.pIndispensableFlg = True Then
					Me.addErrList("E0001", Me.cmb020MEN020F021.Name, Me.lbl019MEN130F021.Text, Nothing)
				End If
				inputCnt -= 1
			End If
			'「更衣」コンボボックスが未入力の場合
			If String.IsNullOrEmpty(Me.cmb023MEN020F021.Text) Then
				If Me.pIndispensableFlg = True Then
					Me.addErrList("E0001", Me.cmb023MEN020F021.Name, Me.lbl022MEN130F021.Text, Nothing)
				End If
				inputCnt -= 1
			End If
			'「排便管理」コンボボックスが未入力の場合
			If String.IsNullOrEmpty(Me.cmb026MEN020F021.Text) Then
				If Me.pIndispensableFlg = True Then
					Me.addErrList("E0001", Me.cmb026MEN020F021.Name, Me.lbl025MEN130F021.Text, Nothing)
				End If
				inputCnt -= 1
			End If
			'「排尿管理」コンボボックスが未入力の場合
			If String.IsNullOrEmpty(Me.cmb029MEN020F021.Text) Then
				If Me.pIndispensableFlg = True Then
					Me.addErrList("E0001", Me.cmb029MEN020F021.Name, Me.lbl028MEN130F021.Text, Nothing)
				End If
				inputCnt -= 1
			End If

			'「食事」コンボボックスが未入力で他項目に入力がある場合
			If String.IsNullOrEmpty(Me.cmb002MEN020F021.Text) AndAlso inputCnt > 0 Then
				Me.addErrList("E0020", Me.cmb002MEN020F021.Name, Me.lbl001MEN130F021.Text, "0～2、9を入力", Nothing)
			End If
			'「移乗」コンボボックスが未入力で他項目に入力がある場合
			If String.IsNullOrEmpty(Me.cmb005MEN020F021.Text) AndAlso inputCnt > 0 Then
				Me.addErrList("E0020", Me.cmb005MEN020F021.Name, Me.lbl004MEN130F021.Text, "0～3、9を入力", Nothing)
			End If
			'「整容」コンボボックスが未入力で他項目に入力がある場合
			If String.IsNullOrEmpty(Me.cmb008MEN020F021.Text) AndAlso inputCnt > 0 Then
				Me.addErrList("E0020", Me.cmb008MEN020F021.Name, Me.lbl007MEN130F021.Text, "0、1、9を入力", Nothing)
			End If
			'「トイレの動作、トイレの使用」コンボボックスが未入力で他項目に入力がある場合
			If String.IsNullOrEmpty(Me.cmb011MEN020F021.Text) AndAlso inputCnt > 0 Then
				Me.addErrList("E0020", Me.cmb011MEN020F021.Name, Me.lbl010MEN130F021.Text, "0～2、9を入力", Nothing)
			End If
			'「入浴」コンボボックスが未入力で他項目に入力がある場合
			If String.IsNullOrEmpty(Me.cmb014MEN020F021.Text) AndAlso inputCnt > 0 Then
				Me.addErrList("E0020", Me.cmb014MEN020F021.Name, Me.lbl013MEN130F021.Text, "0、1、9を入力", Nothing)
			End If
			'「平地歩行」コンボボックスが未入力で他項目に入力がある場合
			If String.IsNullOrEmpty(Me.cmb017MEN020F021.Text) AndAlso inputCnt > 0 Then
				Me.addErrList("E0020", Me.cmb017MEN020F021.Name, Me.lbl016MEN130F021.Text, "0～3、9を入力", Nothing)
			End If
			'「階段」コンボボックスが未入力で他項目に入力がある場合
			If String.IsNullOrEmpty(Me.cmb020MEN020F021.Text) AndAlso inputCnt > 0 Then
				Me.addErrList("E0020", Me.cmb020MEN020F021.Name, Me.lbl019MEN130F021.Text, "0～2、9を入力", Nothing)
			End If
			'「更衣」コンボボックスが未入力で他項目に入力がある場合
			If String.IsNullOrEmpty(Me.cmb023MEN020F021.Text) AndAlso inputCnt > 0 Then
				Me.addErrList("E0020", Me.cmb023MEN020F021.Name, Me.lbl022MEN130F021.Text, "0～2、9を入力", Nothing)
			End If
			'「排便管理」コンボボックスが未入力で他項目に入力がある場合
			If String.IsNullOrEmpty(Me.cmb026MEN020F021.Text) AndAlso inputCnt > 0 Then
				Me.addErrList("E0020", Me.cmb026MEN020F021.Name, Me.lbl025MEN130F021.Text, "0～2、9を入力", Nothing)
			End If
			'「排尿管理」コンボボックスが未入力で他項目に入力がある場合
			If String.IsNullOrEmpty(Me.cmb029MEN020F021.Text) AndAlso inputCnt > 0 Then
				Me.addErrList("E0020", Me.cmb029MEN020F021.Name, Me.lbl028MEN130F021.Text, "0～2、9を入力", Nothing)
			End If

			If Me.getErrCount() > 0 Then
				Me.nextErrForm()
				Return False
			Else
				Return True
			End If
		Catch ex As Exception
			Throw
		End Try
	End Function

#End Region

#Region "オーバーライドメソッド"

	''' ---------------------------------------------
	''' <summary>
	''' 更新前チェック処理
	''' </summary>
	''' <remarks>
	''' 2010/12/06 新規作成　CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Overrides Function PreUpdChkData() As Boolean
		log(clsSysMst.logLevel.DBG, "PreUpdChkData", "更新前チェック処理 Start")
		Try
			' 子コントロールの検証
			Return Me.ValidateChildren
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' -------------------------------------------------------
	''' <summary>
	''' 更新前処理
	''' </summary>
	''' <remarks>
	''' 2010/12/06 新規作成　CS)中岡<BR/>
	''' </remarks>
	''' -------------------------------------------------------
	Public Overrides Function PreUpdProc() As Boolean
		log(clsSysMst.logLevel.DBG, "PreUpdProc", "更新前処理 Start")
		Try
			'入力項目に変更がある場合のみ処理する
			Return Me.chkUpdate()
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' -------------------------------------------------------
	''' <summary>
	''' 更新前確認処理
	''' </summary>
	''' <remarks>
	''' 2010/12/06 新規作成　CS)中岡<BR/>
	''' </remarks>
	''' -------------------------------------------------------
	Public Overrides Function PreUpdConfirm() As MsgBoxResult
		log(clsSysMst.logLevel.DBG, "PreUpdConfirm", "更新前確認処理 Start")
		Try
			If Me.updFlg = clsMENCOMMON.Enum_UpdFlg.eEmpty Then
				Return MsgBoxResult.Yes
			Else
				Return MyBase.PreUpdConfirm()
			End If
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' チェック処理
	''' </summary>
	''' <remarks>
	''' 2010/12/06 新規作成　CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Overrides Function ChkData() As Boolean
		log(clsSysMst.logLevel.DBG, "ChkData", "チェック処理 Start")
		Try
			'全項目未入力ならチェックなし
			Select Case False
				Case String.IsNullOrEmpty(Me.cmb002MEN020F021.Text)	'食事
				Case String.IsNullOrEmpty(Me.cmb005MEN020F021.Text)	'移乗
				Case String.IsNullOrEmpty(Me.cmb008MEN020F021.Text)	'整容
				Case String.IsNullOrEmpty(Me.cmb011MEN020F021.Text)	'トイレの動作、トイレの使用
				Case String.IsNullOrEmpty(Me.cmb014MEN020F021.Text)	'入浴
				Case String.IsNullOrEmpty(Me.cmb017MEN020F021.Text)	'平地歩行
				Case String.IsNullOrEmpty(Me.cmb020MEN020F021.Text)	'階段
				Case String.IsNullOrEmpty(Me.cmb023MEN020F021.Text)	'更衣
				Case String.IsNullOrEmpty(Me.cmb026MEN020F021.Text)	'排便管理
				Case String.IsNullOrEmpty(Me.cmb029MEN020F021.Text)	'排尿管理
				Case Else
					If Me.updFlg <> clsMENCOMMON.Enum_UpdFlg.eEmpty Then
						Me.updFlg = clsMENCOMMON.Enum_UpdFlg.eDelete
					End If
					Return True
			End Select
			'入力チェック
			Me.updFlg = clsMENCOMMON.Enum_UpdFlg.eUpdate
			Return Me.chkInput()
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' -------------------------------------------------------
	''' <summary>
	''' 更新処理
	''' </summary>
	''' <remarks>
	''' 2010/12/06 新規作成　CS)中岡<BR/>
	''' </remarks>
	''' -------------------------------------------------------
	Public Overrides Function UpdProc() As Boolean
		log(clsSysMst.logLevel.DBG, "UpdProc", "更新処理 Start")
		Try
			'入力値保持
			Me.getInputData()
			'戻り値を更新する
			If Me.updFlg <> clsMENCOMMON.Enum_UpdFlg.eEmpty Then
				Me.FormReturn = Enum_FormReturn.OK
			End If
			Return True
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' -------------------------------------------------------
	''' <summary>
	''' 戻り値作成処理
	''' </summary>
	''' <remarks>
	''' 2010/12/06 新規作成　CS)中岡<BR/>
	''' </remarks>
	''' -------------------------------------------------------
	Public Overrides Function DBProc() As Boolean
		log(clsSysMst.logLevel.DBG, "DBProc", "戻り値作成処理 Start")
		Try
			'入力値がある場合
			If Me.updFlg = clsMENCOMMON.Enum_UpdFlg.eUpdate Then
				'ADLスコア設定有りで、呼び出し元画面に戻る
				Me.ReturnValue = Me.pADLValue1 & Me.pADLValue2 & Me.pADLValue3 & Me.pADLValue4 & Me.pADLValue5 & _
								 Me.pADLValue6 & Me.pADLValue7 & Me.pADLValue8 & Me.pADLValue9 & Me.pADLValue10
			Else
				'ADLスコア未設定で、呼び出し元画面に戻る
				Me.ReturnValue = Nothing
			End If
			Return True
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 画面終了後処理
	''' </summary>
	''' <param name="bCancel">キャンセルフラグ</param>
	''' <remarks>
	''' 2010/12/06 新規作成　CS)中岡<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Overrides Sub ClosedProc(ByVal bCancel As Boolean)
		If bCancel Then
			Exit Sub
		End If
		Try
			' 画面終了後処理
			MyBase.ClosedProc(bCancel)
		Catch ex As Exception
			Me.ErrorProc(ex)
		Finally
		End Try
	End Sub

#End Region

End Class